const TransactionResponseModel = require('./TransactionResponseModel')

class TransactionResponse {
    constructor (data) {
        this.slots = data.slots.map((slot) => {
            const clear = () => {
                this.result.resetSlotStatus = this.result.resetSlotStatus.concat([slot.name])
            }

            return Object.assign({}, slot, { clear })
        })
        this.success = typeof data.success === 'boolean' ? data.success : true
        this.error = data.error || ''
        this.sessionId = data.sessionId || ''

        this.result = {

            message: {
                text: data.okMessage.text
            },
            resetSlotStatus: [],
            metadata: data.metadata || ''
        }
    }

    error (err) {
        this.success = false
        this.error = err
    }

    toModel () {
        return new TransactionResponseModel(this)
    }

    setMetadata (value) {
        this.result.metadata = value
    }

    setMessage (value) {
        this.result.message.text = value
    }

    setResetSlotStatus (resetSlotStatus) {
        this.result.resetSlotStatus = resetSlotStatus
    }

    getSlotValue (slotName) {
        const foundSlot =
            this.slots.find(slot => slot.name.toLowerCase() === slotName.toLowerCase())

        if (foundSlot !== undefined) {
            return foundSlot.value
        }

        return foundSlot
    }

    setData (data) {
        if (data.message && typeof data.message.text !== 'undefined') {
            this.setMessage(data.message.text)
        }

        if (Array.isArray(data.resetSlotStatus)) {
            this.setResetSlotStatus(data.resetSlotStatus)
        }
    }
}

module.exports = TransactionResponse
