const utils = require('./utils')
const ValidationResponseModel = require('./ValidationResponseModel')

class ValidationResponse {
    constructor (data) {
        this.initialRequest = data.inputSlotName === null
        this.hasValidatedValue = false
        this.slotName = data.slot.name
        this.inputSlotName = data.inputSlotName
        this.isCurrentSlot = this.slotName === this.inputSlotName
        this.success = true
        this.error = ''
        this.okMessage = data.slot.okMessage
        this.errorMessage = data.slot.errorMessage
        this.missingValueMessage = data.slot.missingValueMessage
        this.originalInputText = data.originalInputText
        this.metadata = data.slot.metadata || {}
        this.sessionId = data.sessionId || ''

        this.result = {

            quickReplies: data.slot.quickReplies || [],
            message: {
                text: ''
            },
            value: data.slot.value,
            status: data.slot.status,
            resetSlotStatus: [],
            metadata: data.slot.metadata || {}
        }
    }

    done () {
        this.hasValidatedValue = true
        this.setMessage(this.okMessage.text.replace('%{value}', this.result.value))
        this.result.status = 'done'
    }

    setError (err) {
        this.success = false
        this.error = err
    }

    setValue (value) {
        this.result.value = utils.removeXss(value)
        this.done()
    }

    setMetadata (value) {
        this.result.metadata = value
    }

    setMessage (value) {
        this.result.message.text = value
    }

    getMessage () {
        return this.result.message.text
    }

    setQuickReplies (quickReplies) {
        if (Array.isArray(quickReplies)) {
            this.result.quickReplies = quickReplies
        }
    }

    addQuickReply (quickReply) {
        this.result.quickReplies.push(quickReply)
    }

    setData (data) {
        if (Array.isArray(data.quickReplies)) {
            this.setQuickReplies(data.quickReplies)
        }

        if (data.message && typeof data.message.text !== 'undefined') {
            this.setMessage(data.message.text)
        }

        if (typeof data.value !== 'undefined') {
            this.setValue(data.value)
        }
    }

    setResetSlotStatus (resetSlotStatus) {
        this.result.resetSlotStatus = resetSlotStatus
    }

    toModel () {
        if (!this.hasValidatedValue && !this.getMessage() && this.success) {
            if (this.isCurrentSlot) {
                this.setMessage(this.errorMessage.text)
            } else {
                this.setMessage(this.missingValueMessage.text)
            }
        }

        return new ValidationResponseModel(this)
    }
}

module.exports = ValidationResponse
