const TransactionResponse = require('../src/TransactionResponse')
const mockTransactionPayload = require('../mocks/mockTransactionPayload')

describe('TransactionResponse', () => {
    it('can be constructed with the transaction webhook payload', () => {
        const payload = mockTransactionPayload()

        const instantiate = () => new TransactionResponse(payload)

        expect(instantiate).not.toThrow()
    })

    it('throws without the transaction webhook payload', () => {
        const instantiate = () => new TransactionResponse()

        expect(instantiate).toThrow()
    })

    it('should return a model of a successful transaction', () => {
        const payload = mockTransactionPayload()

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeTruthy()
        expect(response.error).toBe('')
    })

    it('should return a model of a successful transaction with error message', () => {
        const payload = mockTransactionPayload({
            'error': 'warning message'
        })

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeTruthy()
        expect(response.error).toBe('warning message')
    })

    it('should return a model of an unsuccessful transaction', () => {
        const payload = mockTransactionPayload({
            'success': false,
            'error': 'an error message'
        })

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeFalsy()
        expect(response.error).toBe('an error message')
    })

    it('should return a model of an unknown result transaction', () => {
        const payload = mockTransactionPayload({
            'success': undefined,
            'error': undefined
        })

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeTruthy()
        expect(response.error).toBe('')
    })

    it('should return a model of a transaction with success type string', () => {
        const payload = mockTransactionPayload({
            'success': 'false'
        })

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeTruthy()
    })

    it('should return a model of a transaction with success empty string', () => {
        const payload = mockTransactionPayload({
            'success': ''
        })

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeTruthy()
    })

    it('should return a model of a transaction with success type number', () => {
        const payload = mockTransactionPayload({
            'success': 0
        })

        const response = (new TransactionResponse(payload)).toModel()
        expect(response.success).toBeTruthy()
    })
})
