const ValidationResponse = require('../src/ValidationResponse')
const { mockValidationPayload, mockSlot } = require('../mocks')

describe('ValidationResponse', () => {
    describe('constructor', () => {
        it('can be constructed with the validation webhook payload', () => {
            const payload = mockValidationPayload()

            const instantiate = () => new ValidationResponse(payload)

            expect(instantiate).not.toThrow()
        })

        it('throws without a validation webhook payload', () => {
            const instantiate = () => new ValidationResponse()

            expect(instantiate).toThrow()
        })
    })

    describe('initialRequest', () => {
        it('should be true on the initial request', () => {
            const payload = mockValidationPayload({ inputSlotName: null })

            const instance = new ValidationResponse(payload)

            expect(instance.initialRequest).toBe(true)
        })

        it('is false when inputSlotName is defined', () => {
            const payload = mockValidationPayload({ inputSlotName: 'bla' })

            const instance = new ValidationResponse(payload)

            expect(instance.initialRequest).toBe(false)
        })
    })

    describe('isCurrentSlot', () => {
        it('is true when the current slot is the active one', () => {
            const payload = mockValidationPayload({
                inputSlotName: 'the current slot',
                slot: mockSlot({ name: 'the current slot' })
            })

            const instance = new ValidationResponse(payload)

            expect(instance.isCurrentSlot).toBe(true)
        })

        it('is false when current slot is not the active one', () => {
            const payload = mockValidationPayload({
                inputSlotName: 'the current slot',
                slot: mockSlot({ name: 'another slot' })
            })

            const instance = new ValidationResponse(payload)

            expect(instance.isCurrentSlot).toBe(false)
        })
    })
})
