const ValidationResponse = require('../src/ValidationResponse')
const mockValidationPayload = require('../mocks/mockValidationPayload')
const addValidationSlotMiddleware = require('../src/addValidationSlotMiddleware')

describe('addValidationSlotMiddleware', () => {
    it('should call error handling middleware when the body is not parsed', () => {
        const next = jest.fn()
        const res = {}
        const req = { body: '{"sessionId": "123123-123-123"}' }

        addValidationSlotMiddleware(req, res, next)

        expect(next).toHaveBeenCalledWith(expect.any(Error))
    })

    it('should call error handling middleware when the json payload seems to not be from a webhook', () => {
        const next = jest.fn()
        const res = {}
        const req = { body: { something: 'else' } }

        addValidationSlotMiddleware(req, res, next)

        expect(next).toHaveBeenCalledWith(expect.any(Error))
    })

    it('should call error handling middleware when the json payload seems to not be from a webhook', () => {
        const next = jest.fn()
        const res = {}
        const req = { body: mockValidationPayload() }

        addValidationSlotMiddleware(req, res, next)

        expect(res.locals.dcxValidationSlot).toEqual(new ValidationResponse(req.body))
    })
})
